# ModelFiles

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**structure_file** | **str** |  | [optional] [readonly] 
**systems_file** | **str** |  | [optional] [readonly] 
**map_file** | **str** |  | [optional] [readonly] 
**gltf_file** | **str** |  | [optional] [readonly] 
**gltf_with_openings_file** | **str** |  | [optional] [readonly] 
**bvh_tree_file** | **str** |  | [optional] [readonly] 
**viewer_360_file** | **str** |  | [optional] [readonly] 
**xkt_file** | **str** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


